#[repr(C)]pub struct OrderFillVoided {Show 24 fields
pub trader_id: TraderId,
pub strategy_id: StrategyId,
pub instrument_id: InstrumentId,
pub client_order_id: ClientOrderId,
pub venue_order_id: VenueOrderId,
pub account_id: AccountId,
pub correction_id: Ustr,
pub trade_id: TradeId,
pub voided_qty: Quantity,
pub commission_voided: Option<Money>,
pub order_side: OrderSide,
pub order_type: OrderType,
pub last_px: Price,
pub currency: Currency,
pub liquidity_side: LiquiditySide,
pub position_id: Option<PositionId>,
pub reason: Option<Ustr>,
pub info: Option<IndexMap<Ustr, Ustr>>,
pub event_id: UUID4,
pub ts_event: UnixNanos,
pub ts_init: UnixNanos,
pub reconciliation: bool,
pub is_reopened: bool,
pub causation_id: Option<UUID4>,
}Expand description
Records that a cumulative fill quantity no longer has economic effect.
The correction identity, voided quantity, and commission are cumulative for the referenced
trade. is_reopened records positive evidence that the corrected order is executable again
and therefore requires the referenced fill to have been applied locally. Without a local fill,
a non-reopened correction is an authoritative terminal order void.
Fields
trader_id: TraderIdstrategy_id: StrategyIdinstrument_id: InstrumentIdclient_order_id: ClientOrderIdvenue_order_id: VenueOrderIdaccount_id: AccountIdcorrection_id: Ustrtrade_id: TradeIdvoided_qty: Quantitycommission_voided: Option<Money>order_side: OrderSideorder_type: OrderTypelast_px: Pricecurrency: Currencyliquidity_side: LiquiditySideposition_id: Option<PositionId>reason: Option<Ustr>info: Option<IndexMap<Ustr, Ustr>>event_id: UUID4ts_event: UnixNanosts_init: UnixNanosreconciliation: boolis_reopened: boolcausation_id: Option<UUID4>Implementations
Sourceimpl OrderFillVoided
impl OrderFillVoided
pub fn new( trader_id: TraderId, strategy_id: StrategyId, instrument_id: InstrumentId, client_order_id: ClientOrderId, venue_order_id: VenueOrderId, account_id: AccountId, correction_id: Ustr, trade_id: TradeId, voided_qty: Quantity, commission_voided: Option<Money>, order_side: OrderSide, order_type: OrderType, last_px: Price, currency: Currency, liquidity_side: LiquiditySide, position_id: Option<PositionId>, reason: Option<Ustr>, info: Option<IndexMap<Ustr, Ustr>>, event_id: UUID4, ts_event: UnixNanos, ts_init: UnixNanos, reconciliation: bool, is_reopened: bool, ) -> Self